# Info GTK CLI

[![PyPi Package Version](https://img.shields.io/pypi/v/info-gtk)](https://pypi.org/project/info-gtk/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/info-gtk)](https://pypi.org/project/info-gtk/)
[![LICENSE](https://img.shields.io/github/license/dapodix/info-gtk)](https://github.com/dapodix/info-gtk/blob/main/LICENSE)
[![Tests](https://github.com/dapodix/info-gtk/workflows/Tests/badge.svg)](https://github.com/dapodix/info-gtk/actions?query=workflow%3ATests)
[![codecov](https://codecov.io/gh/dapodix/info-gtk/branch/main/graph/badge.svg)](https://codecov.io/gh/dapodix/info-gtk)

CLI / SDK python [info-gtk](https://info.gtk.kemdikbud.go.id/).

## Fitur yang akan datang

Berikut fitur yang akan direncanakan untuk aplikasi ini.

- Export data ke excel
- Download / Print masal

## Donasi

Jika anda ingin melakukan donasi untuk kami, bisa menghubungi kami melalui [WhatsApp](https://wa.me/6287725780404) ataupun [Telegram](https://t.me/hexatester).

## Legal / Hukum

Kode ini sama sekali tidak berafiliasi dengan, diizinkan, dipelihara, disponsori atau didukung oleh Kemdikbud atau afiliasi atau anak organisasinya. Ini adalah perangkat lunak yang independen dan tidak resmi. _Gunakan dengan risiko Anda sendiri_.
